/**
 *    Copyright (C) 2021 Graham Leggett <minfrin@sharp.fm>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/*
 * redwax_p11kit - PKCS11 routines for munching certificates
 *
 */

#ifndef REDWAX_P11KIT_H
#define REDWAX_P11KIT_H

#include "config.h"

#if HAVE_P11_KIT_MODULES_LOAD_AND_INITIALIZE

void redwax_add_default_p11kit_hooks(apr_pool_t *pool);

#endif
#endif
